aboutsummaryrefslogtreecommitdiff
path: root/src/lib/kdb
diff options
context:
space:
mode:
authorGreg Hudson <ghudson@mit.edu>2020-06-24 20:48:14 -0400
committerGreg Hudson <ghudson@mit.edu>2020-09-07 12:20:16 -0400
commit10eb93809b1af06e2b1147aee2e3e50058ba1bbd (patch)
tree179b7b7ebe3174f3a87c530285a11908680dc6ac /src/lib/kdb
parentbfd407703a938573610af3f17aad4d5ebad615fd (diff)
downloadkrb5-10eb93809b1af06e2b1147aee2e3e50058ba1bbd.zip
krb5-10eb93809b1af06e2b1147aee2e3e50058ba1bbd.tar.gz
krb5-10eb93809b1af06e2b1147aee2e3e50058ba1bbd.tar.bz2
Use the term "primary KDC" in source and docs
Where it does not affect program behavior, use the term "primary KDC". This commit does not change any profile variables, DNS labels, pathnames, or externally visible identifiers, nor does it change the term "master key". ticket: 8921 (new)
Diffstat (limited to 'src/lib/kdb')
-rw-r--r--src/lib/kdb/kdb5.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lib/kdb/kdb5.c b/src/lib/kdb/kdb5.c
index a3fc0bf..47e9b31 100644
--- a/src/lib/kdb/kdb5.c
+++ b/src/lib/kdb/kdb5.c
@@ -104,13 +104,13 @@ kdb_unlock_list()
k5_mutex_unlock(&db_lock);
}
/* Return true if the ulog is mapped in the master role. */
static inline krb5_boolean
logging(krb5_context context)
{
kdb_log_context *log_ctx = context->kdblog_context;
- return log_ctx != NULL && log_ctx->iproprole == IPROP_MASTER &&
+ return log_ctx != NULL && log_ctx->iproprole == IPROP_PRIMARY &&
log_ctx->ulog != NULL;
}
@@ -104,13 +104,13 @@ kdb_unlock_list()
k5_mutex_unlock(&db_lock);
}
-/* Return true if the ulog is mapped in the master role. */
+/* Return true if the ulog is mapped in the primary role. */
static inline krb5_boolean
logging(krb5_context context)